EXPORTS
	??0TPanoramaLens@@QAE@PAM0M0KK@Z @ 1 NONAME ; TPanoramaLens::TPanoramaLens(float *, float *, float, float *, unsigned long, unsigned long)
	??0TPanoramaLens@@QAE@XZ @ 2 NONAME ; TPanoramaLens::TPanoramaLens(void)
	?AddBufferL@CImagePanorama@@QAEXABVTDesC8@@AAVCPanoramaTransform@@@Z @ 3 NONAME ; void CImagePanorama::AddBufferL(class TDesC8 const &, class CPanoramaTransform &)
	?AddFileL@CImagePanorama@@QAEXABVTDesC16@@AAVCPanoramaTransform@@@Z @ 4 NONAME ; void CImagePanorama::AddFileL(class TDesC16 const &, class CPanoramaTransform &)
	?AddImageL@CImagePanorama@@QAEXABVCFbsBitmap@@AAVCPanoramaTransform@@@Z @ 5 NONAME ; void CImagePanorama::AddImageL(class CFbsBitmap const &, class CPanoramaTransform &)
	?AddImageL@CImagePanorama@@QAEXABVCImageFrame@@AAVCPanoramaTransform@@@Z @ 6 NONAME ; void CImagePanorama::AddImageL(class CImageFrame const &, class CPanoramaTransform &)
	?CurrentImageSizeL@CImagePanorama@@QAEXAAVTSize@@@Z @ 7 NONAME ; void CImagePanorama::CurrentImageSizeL(class TSize &)
	?Extension@CImagePanorama@@QAEPAXVTUid@@@Z @ 8 NONAME ; void * CImagePanorama::Extension(class TUid)
	?Extension@CVFTracker@@QAEPAXVTUid@@@Z @ 9 NONAME ; void * CVFTracker::Extension(class TUid)
	?GetDirection@CPanoramaTransform@@QAEXAAW4TDirection@@@Z @ 10 NONAME ; void CPanoramaTransform::GetDirection(enum TDirection &)
	?GetDirection@CPanoramaTransform@@QAEXAAW4TDirection@@AAH@Z @ 11 NONAME ; void CPanoramaTransform::GetDirection(enum TDirection &, int &)
	?GetTranslation@CPanoramaTransform@@QBEXAAVTPoint@@AAVTSize@@@Z @ 12 NONAME ; void CPanoramaTransform::GetTranslation(class TPoint &, class TSize &) const
	?InitializeL@CImagePanorama@@QAEXABVTSize@@ABVTPanoramaLens@@ABW4TDirection@@@Z @ 13 NONAME ; void CImagePanorama::InitializeL(class TSize const &, class TPanoramaLens const &, enum TDirection const &)
	?InitializeL@CVFTracker@@QAEXABVTSize@@@Z @ 14 NONAME ; void CVFTracker::InitializeL(class TSize const &)
	?IsTimeToCapture@CVFTracker@@QBEHAAW4TDirection@@@Z @ 15 NONAME ; int CVFTracker::IsTimeToCapture(enum TDirection &) const
	?IsTimeToCapture@CVFTracker@@QBEHAAW4TDirection@@H@Z @ 16 NONAME ; int CVFTracker::IsTimeToCapture(enum TDirection &, int) const
	?NewL@CImagePanorama@@SAPAV1@XZ @ 17 NONAME ; class CImagePanorama * CImagePanorama::NewL(void)
	?NewL@CPanoramaTransform@@SAPAV1@XZ @ 18 NONAME ; class CPanoramaTransform * CPanoramaTransform::NewL(void)
	?NewL@CVFTracker@@SAPAV1@XZ @ 19 NONAME ; class CVFTracker * CVFTracker::NewL(void)
	?RegisterImageL@CVFTracker@@QAEXABVCFbsBitmap@@AAVCPanoramaTransform@@@Z @ 20 NONAME ; void CVFTracker::RegisterImageL(class CFbsBitmap const &, class CPanoramaTransform &)
	?RegisterImageL@CVFTracker@@QAEXABVCImageFrame@@AAVCPanoramaTransform@@@Z @ 21 NONAME ; void CVFTracker::RegisterImageL(class CImageFrame const &, class CPanoramaTransform &)
	?RenderL@CImagePanorama@@QAEXAAPAVHBufC8@@@Z @ 22 NONAME ; void CImagePanorama::RenderL(class HBufC8 * &)
	?RenderL@CImagePanorama@@QAEXAAPAVHBufC8@@KABVTSize@@HABVTUid@@@Z @ 23 NONAME ; void CImagePanorama::RenderL(class HBufC8 * &, unsigned long, class TSize const &, int, class TUid const &)
	?RenderL@CImagePanorama@@QAEXAAVRFile@@@Z @ 24 NONAME ; void CImagePanorama::RenderL(class RFile &)
	?RenderL@CImagePanorama@@QAEXAAVRFile@@ABVTSize@@HABVTUid@@@Z @ 25 NONAME ; void CImagePanorama::RenderL(class RFile &, class TSize const &, int, class TUid const &)
	?RenderL@CImagePanorama@@QAEXABVCFbsBitmap@@@Z @ 26 NONAME ; void CImagePanorama::RenderL(class CFbsBitmap const &)
	?RenderL@CImagePanorama@@QAEXABVCFbsBitmap@@H@Z @ 27 NONAME ; void CImagePanorama::RenderL(class CFbsBitmap const &, int)
	?RenderL@CImagePanorama@@QAEXABVCImageFrame@@@Z @ 28 NONAME ; void CImagePanorama::RenderL(class CImageFrame const &)
	?RenderL@CImagePanorama@@QAEXABVCImageFrame@@H@Z @ 29 NONAME ; void CImagePanorama::RenderL(class CImageFrame const &, int)
	?RenderL@CImagePanorama@@QAEXABVTDesC16@@@Z @ 30 NONAME ; void CImagePanorama::RenderL(class TDesC16 const &)
	?RenderL@CImagePanorama@@QAEXABVTDesC16@@ABVTSize@@HABVTUid@@@Z @ 31 NONAME ; void CImagePanorama::RenderL(class TDesC16 const &, class TSize const &, int, class TUid const &)
	?Reset@CVFTracker@@QAEXXZ @ 32 NONAME ; void CVFTracker::Reset(void)
	?SetDirection@CPanoramaTransform@@QAEXAAW4TDirection@@@Z @ 33 NONAME ; void CPanoramaTransform::SetDirection(enum TDirection &)
	?SetDirection@CPanoramaTransform@@QAEXAAW4TDirection@@H@Z @ 34 NONAME ; void CPanoramaTransform::SetDirection(enum TDirection &, int)
	?SetTranslationL@CPanoramaTransform@@QAEXABVTPoint@@ABVTSize@@@Z @ 35 NONAME ; void CPanoramaTransform::SetTranslationL(class TPoint const &, class TSize const &)
	??1CVFTracker@@UAE@XZ @ 36 NONAME ; CVFTracker::~CVFTracker(void)
	??1CImagePanorama@@UAE@XZ @ 37 NONAME ; CImagePanorama::~CImagePanorama(void)
	??1CPanoramaTransform@@UAE@XZ @ 38 NONAME ; CPanoramaTransform::~CPanoramaTransform(void)

